summaryrefslogtreecommitdiffstats
path: root/Source/cmMakefile.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-07-31 15:29:21 (GMT)
committerBrad King <brad.king@kitware.com>2001-07-31 15:29:21 (GMT)
commitcfa25e9e1a48938378c300dfbf5b33e62018f295 (patch)
tree146a67f93597b35e69c38255aaddbd0547b19f81 /Source/cmMakefile.cxx
parent489e91a1f7b1d5d9542cb965b47a44f99878c7a5 (diff)
downloadCMake-cfa25e9e1a48938378c300dfbf5b33e62018f295.zip
CMake-cfa25e9e1a48938378c300dfbf5b33e62018f295.tar.gz
CMake-cfa25e9e1a48938378c300dfbf5b33e62018f295.tar.bz2
ENH: Added INSTALL_PROGRAMS command and corresponding support. This involved splitting cmTarget::INSTALL into INSTALL_FILES and INSTALL_PROGRAMS enum values. INSTALL_FILES no longer adds execute permission. The INSTALL_PROGRAMS commnad takes either a list of explicit names, or a regex. It will not expand source lists like the INSTALL_FILES command will.
Diffstat (limited to 'Source/cmMakefile.cxx')
-rw-r--r--Source/cmMakefile.cxx8
1 files changed, 5 insertions, 3 deletions
diff --git a/Source/cmMakefile.cxx b/Source/cmMakefile.cxx
index 19cc386..a509de8 100644
--- a/Source/cmMakefile.cxx
+++ b/Source/cmMakefile.cxx
@@ -122,11 +122,13 @@ void cmMakefile::AddDefaultCommands()
#if defined(__APPLE__)
this->AddDefinition("APPLE", "1");
#endif
// always creat an empty install target
cmTarget target;
- target.SetType(cmTarget::INSTALL);
target.SetInAll(false);
- m_Targets.insert(cmTargets::value_type("INSTALL",target));
+ target.SetType(cmTarget::INSTALL_FILES);
+ m_Targets.insert(cmTargets::value_type("INSTALL_FILES", target));
+ target.SetType(cmTarget::INSTALL_PROGRAMS);
+ m_Targets.insert(cmTargets::value_type("INSTALL_PROGRAMS", target));
}
cmMakefile::~cmMakefile()
@@ -122,11 +122,13 @@ void cmMakefile::AddDefaultCommands()
this->AddDefinition("APPLE", "1");
#endif
- // always creat an empty install target
+ // always creat an empty install targets for files and programs.
cmTarget target;